@@ -17,7 +17,7 @@ import matplotlib.pyplot as plt
 import matplotlib
 import numpy as np
 
-__version__ = '0.5.0'
+from ._version import *
 
 
 def system_has_latex():
@@ -982,6 +982,46 @@ the positions of the ticks.
     return lines
 
 
+def fit_powerlaw(xdata, ydata, prefactor=None, exponent=None):
+    r'''
+Fit a powerlaw by converting the data to their logarithm and fitting a straight line.
+This function does not support more customised operation like fitting an offset,
+but custom code can be easily written by copy/pasting from here.
+
+:param array_like xdata: Data points along the x-axis.
+:param array_like ydata: Data points along the y-axis.
+:param float prefactor: Specify a prefactor (fitted if not specified).
+:param float exponent: Specify a exponent (fitted if not specified).
+:return: prefactor, exponent
+    '''
+
+    i = np.logical_and(xdata > 0, ydata > 0)
+    logx = np.log(xdata[i])
+    logy = np.log(ydata[i])
+    i = np.logical_or(np.isnan(logx), np.isnan(logy))
+    logy = logy[~i]
+    logx = logx[~i]
+
+    # fit prefactor and exponent
+    if prefactor is None and exponent is None:
+        param = np.polyfit(logx, logy, 1)
+        return np.exp(param[1]), param[0]
+
+    import scipy.optimize
+
+    # fit exponent only
+    if exponent is None:
+        log_prefactor = np.log(prefactor)
+        f = lambda logx, exponent: log_prefactor + exponent * logx
+        param, _ = scipy.optimize.curve_fit(f, logx, logy)
+        return prefactor, param[0]
+
+    # fit prefactor only
+    f = lambda logx, log_prefactor: log_prefactor + exponent * logx
+    param, _ = scipy.optimize.curve_fit(f, logx, logy)
+    return np.exp(param[0]), exponent
+
+
 def random_from_cdf(shape, P, x, linspace=False, shuffle=True):
     r'''
 Generate a random number based on a discrete cumulative probability density function.
@@ -1098,6 +1138,30 @@ Merge bins with right-neighbour until each bin has a minimum number of data-poin
             bins = np.hstack((bins[:(idx + 1)], bins[(idx + 2):]))
 
 
+def histogram_bin_edges_integer(bin_edges):
+    r'''
+Merge bins not encompassing an integer with the preceding bin.
+For example: a bin with edges ``[1.1, 1.9]`` is removed, but ``[0.9, 1.1]`` is not removed.
+
+:param array_like bin_edges: Bin-edges.
+:return: Bin-edges.
+    '''
+
+    if type(bin_edges) == list:
+        bin_edges = np.array(bin_edges)
+
+    assert bin_edges.size > 1
+
+    i = np.where(np.diff(np.floor(bin_edges)) >= 1)[0]
+
+    if i[0] > 0:
+        i[0] = 0
+
+    i = list(i) + [bin_edges.size - 1]
+
+    return bin_edges[i]
+
+
 def histogram_bin_edges(
         data,
         bins=10,
@@ -1208,11 +1272,7 @@ Determine bin-edges.
     # select only bins that encompass an integer (and retain the original bounds)
 
     if integer:
-
-        idx = np.where(np.diff(np.floor(bin_edges)) >= 1)[0]
-        idx = np.unique(np.hstack((0, idx, len(bin_edges) - 1)))
-
-        bin_edges = bin_edges[idx]
+        bin_edges = histogram_bin_edges_integer(bin_edges)
 
     # return
 
